@@ -5,6 +5,6 @@ from pydantic import BaseModel, HttpUrl, EmailStr
 
 class FAMetadata(BaseModel):
     contacts: List[EmailStr]
-    federation_api_endpoint: HttpUrl
+    federation_fetch_endpoint: HttpUrl
     homepage_uri: HttpUrl
     name: str
