@@ -15,3 +15,10 @@ def oidc_provider_logo():
     return f"""{settings.STATIC_URL}{OIDCFED_PROVIDER_PROFILES_MEDIA.get(
         OIDCFED_DEFAULT_PROVIDER_PROFILE, {}
     ).get('logo', "")}"""
+
+
+@register.simple_tag
+def oidc_provider_arc_value_position():
+    return f"""{OIDCFED_PROVIDER_PROFILES_MEDIA.get(
+        OIDCFED_DEFAULT_PROVIDER_PROFILE, {}
+    ).get('arc_position', "")}"""
