@@ -123,7 +123,6 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
             )
 
         if not authz:
-            # TODO: verify error message and status
             context = {
                 "error": "unauthorized request",
                 "error_description": _("Authentication not found"),
@@ -141,7 +140,6 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
             sub=authz_token.authz_request.client_id
         ).first()
         if not self.rp_conf:
-            # TODO: verify error message and status
             context = {
                 "error": "invalid request",
                 "error_description": _("Relay party not found"),
@@ -159,7 +157,6 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
             code_verifier=authz_data.get("code_verifier"),
         )
         if not token_response:
-            # TODO: verify error message
             context = {
                 "error": "invalid token response",
                 "error_description": _("Token response seems not to be valid"),
@@ -188,7 +185,10 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
         op_id_jwk = self.get_jwk_from_jwt(id_token, jwks)
 
         if not op_ac_jwk or not op_id_jwk:
-            # TODO: verify error message and status
+            logger.warning(
+                "Token signature validation error, "
+                f"the tokens were signed with a different kid from: {jwks}."
+            )
             context = {
                 "error": "invalid_token",
                 "error_description": _("Authentication token seems not to be valid."),
@@ -197,8 +197,10 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
 
         try:
             verify_jws(access_token, op_ac_jwk)
-        except Exception:
-            # TODO: verify error message
+        except Exception as e:
+            logger.warning(
+                f"Access Token signature validation error: {e} "
+            )
             context = {
                 "error": "token verification failed",
                 "error_description": _("Authentication token validation error."),
@@ -207,8 +209,10 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
 
         try:
             verify_jws(id_token, op_id_jwk)
-        except Exception:
-            # TODO: verify error message
+        except Exception as e:
+            logger.warning(
+                f"ID Token signature validation error: {e} "
+            )
             context = {
                 "error": "token verification failed",
                 "error_description": _("ID token validation error."),
@@ -234,7 +238,10 @@ class SpidCieOidcRpCallbackView(View, SpidCieOidcRp, OidcUserInfo, OAuth2Authori
             verify=HTTPC_PARAMS,
         )
         if not userinfo:
-            # TODO: verify error message
+            logger.warning(
+                "Userinfo request failed for state: "
+                f"{authz.state} to {authz.provider_id}"
+            )
             context = {
                 "error": "invalid userinfo response",
                 "error_description": _("UserInfo response seems not to be valid"),
